@@ -36,6 +36,7 @@ var searchData=
   ['searchdescriptor',['SearchDescriptor',['../servicecom_1_1sun_1_1star_1_1util_1_1SearchDescriptor.html',1,'com::sun::star::util']]],
   ['searchinfo',['SearchInfo',['../structcom_1_1sun_1_1star_1_1ucb_1_1SearchInfo.html',1,'com::sun::star::ucb']]],
   ['searchoptions',['SearchOptions',['../structcom_1_1sun_1_1star_1_1util_1_1SearchOptions.html',1,'com::sun::star::util']]],
+  ['searchoptions2',['SearchOptions2',['../structcom_1_1sun_1_1star_1_1util_1_1SearchOptions2.html',1,'com::sun::star::util']]],
   ['searchresult',['SearchResult',['../structcom_1_1sun_1_1star_1_1util_1_1SearchResult.html',1,'com::sun::star::util']]],
   ['section',['Section',['../servicecom_1_1sun_1_1star_1_1report_1_1Section.html',1,'com::sun::star::report']]],
   ['sectionfilelink',['SectionFileLink',['../structcom_1_1sun_1_1star_1_1text_1_1SectionFileLink.html',1,'com::sun::star::text']]],
@@ -61,8 +62,8 @@ var searchData=
   ['setexpression',['SetExpression',['../servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1SetExpression.html',1,'com::sun::star::text::fieldmaster']]],
   ['setexpression',['SetExpression',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html',1,'com::sun::star::text::textfield']]],
   ['setpropertytolerantfailed',['SetPropertyTolerantFailed',['../structcom_1_1sun_1_1star_1_1beans_1_1SetPropertyTolerantFailed.html',1,'com::sun::star::beans']]],
-  ['settings',['Settings',['../servicecom_1_1sun_1_1star_1_1document_1_1Settings.html',1,'com::sun::star::document']]],
   ['settings',['Settings',['../servicecom_1_1sun_1_1star_1_1frame_1_1Settings.html',1,'com::sun::star::frame']]],
+  ['settings',['Settings',['../servicecom_1_1sun_1_1star_1_1document_1_1Settings.html',1,'com::sun::star::document']]],
   ['setupdate',['SetUpdate',['../servicecom_1_1sun_1_1star_1_1configuration_1_1SetUpdate.html',1,'com::sun::star::configuration']]],
   ['shadowformat',['ShadowFormat',['../structcom_1_1sun_1_1star_1_1table_1_1ShadowFormat.html',1,'com::sun::star::table']]],
   ['shadowproperties',['ShadowProperties',['../servicecom_1_1sun_1_1star_1_1drawing_1_1ShadowProperties.html',1,'com::sun::star::drawing']]],
@@ -149,9 +150,9 @@ var searchData=
   ['standarddiagramcreationparameters',['StandardDiagramCreationParameters',['../servicecom_1_1sun_1_1star_1_1chart2_1_1StandardDiagramCreationParameters.html',1,'com::sun::star::chart2']]],
   ['startmodule',['StartModule',['../servicecom_1_1sun_1_1star_1_1frame_1_1StartModule.html',1,'com::sun::star::frame']]],
   ['statechangeinprogressexception',['StateChangeInProgressException',['../exceptioncom_1_1sun_1_1star_1_1embed_1_1StateChangeInProgressException.html',1,'com::sun::star::embed']]],
+  ['statement',['Statement',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Statement.html',1,'com::sun::star::sdbcx']]],
   ['statement',['Statement',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1Statement.html',1,'com::sun::star::sdbc']]],
   ['statement',['Statement',['../structcom_1_1sun_1_1star_1_1rdf_1_1Statement.html',1,'com::sun::star::rdf']]],
-  ['statement',['Statement',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Statement.html',1,'com::sun::star::sdbcx']]],
   ['statusbarcontroller',['StatusbarController',['../servicecom_1_1sun_1_1star_1_1frame_1_1StatusbarController.html',1,'com::sun::star::frame']]],
   ['statusbarcontrollerfactory',['StatusbarControllerFactory',['../servicecom_1_1sun_1_1star_1_1frame_1_1StatusbarControllerFactory.html',1,'com::sun::star::frame']]],
   ['statusindicatorfactory',['StatusIndicatorFactory',['../servicecom_1_1sun_1_1star_1_1task_1_1StatusIndicatorFactory.html',1,'com::sun::star::task']]],
@@ -186,6 +187,7 @@ var searchData=
   ['svgtools',['SvgTools',['../servicecom_1_1sun_1_1star_1_1graphic_1_1SvgTools.html',1,'com::sun::star::graphic']]],
   ['symbol',['Symbol',['../structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html',1,'com::sun::star::chart2']]],
   ['symboldescriptor',['SymbolDescriptor',['../structcom_1_1sun_1_1star_1_1formula_1_1SymbolDescriptor.html',1,'com::sun::star::formula']]],
+  ['syncdbussessionhelper',['SyncDbusSessionHelper',['../serviceorg_1_1freedesktop_1_1PackageKit_1_1SyncDbusSessionHelper.html',1,'org::freedesktop::PackageKit']]],
   ['synchronousframeloader',['SynchronousFrameLoader',['../servicecom_1_1sun_1_1star_1_1frame_1_1SynchronousFrameLoader.html',1,'com::sun::star::frame']]],
   ['systemclipboard',['SystemClipboard',['../servicecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1SystemClipboard.html',1,'com::sun::star::datatransfer::clipboard']]],
   ['systemdependentxwindow',['SystemDependentXWindow',['../structcom_1_1sun_1_1star_1_1awt_1_1SystemDependentXWindow.html',1,'com::sun::star::awt']]],
